4. tofu.plugins — tofu v1.1

# 4. tofu.plugins

In an effort to adapt ToFu to several experiments and ensure a smooth use for non-specialists users, plugins can be developped to adapt ToFu to the local specificities of each laboratory or environment (local computer systems and networks, local geometry and nomenclature, local data storing systems...).

While ToFu in itself is open-source, the plugins, which concentrate everything that is machine-specific, are writen on demand and customized for the local needs, they remain on the local servers and are not provided on the GitHub page of ToFu. It is via the laboratories that you may have access to them.

The following plugins have been / are being developped:

## 4.1. Machine-oriented plugins

- 4.1.1. AUG
- 4.1.2. ITER

## 4.2. Code-oriented plugins

1. CAID

## 4.3. Indices and tables

- Homepage
- Index
- Module Index
- Search Page